package com.cj.jiaqingjiayi.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

import com.cj.jiaqingjiayi.common.BaseResponse;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.common.ResultUtils;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.CommonRequest;
import com.cj.jiaqingjiayi.model.domain.Collect;
import com.cj.jiaqingjiayi.model.domain.User;
import com.cj.jiaqingjiayi.model.request.collect.CollectAddRequest;
import com.cj.jiaqingjiayi.service.CollectService;
import com.cj.jiaqingjiayi.service.UserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

@RestController
@Slf4j
@RequestMapping("/collect")
@Api(tags = "收藏接口")
public class CollectController {

    @Resource
    private CollectService collectService;

    @Resource
    private UserService userService;

    /**
     * 添加收藏
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加收藏")
    public BaseResponse<Boolean> addCollect(@RequestBody CollectAddRequest collectAddRequest, HttpServletRequest request) {
        if (collectAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        collectService.validCollect(collectAddRequest);
        Collect collect = new Collect();
        BeanUtils.copyProperties(collectAddRequest, collect);
        Boolean result = collectService.addCollect(collect, request);
        ThrowUtils.throwIf(!result, ErrorCode.SYSTEM_ERROR);
        return ResultUtils.success(true);
    }

    /**
     * 删除一条收藏
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除一条收藏")
    public BaseResponse<Boolean> deleteCollect(@RequestBody CommonRequest commonRequest) {
        if (commonRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Long id = commonRequest.getId();
        LambdaQueryWrapper<Collect> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(Collect::getId, id);
        boolean remove = collectService.remove(wrapper);
        ThrowUtils.throwIf(!remove, ErrorCode.SYSTEM_ERROR);
        return ResultUtils.success(true);
    }

    /**
     * 删除所有收藏
     */
    @PostMapping("/delete/all")
    @ApiOperation(value = "删除所有收藏")
    public BaseResponse<Boolean> deleteCollectAll(HttpServletRequest request) {
        User loginUser = userService.getLoginUser(request);
        Long loginUserId = loginUser.getId();
        LambdaQueryWrapper<Collect> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(Collect::getUserId, loginUserId);
        boolean remove = collectService.remove(wrapper);
        ThrowUtils.throwIf(!remove, ErrorCode.SYSTEM_ERROR);
        return ResultUtils.success(true);
    }

    /**
     * 查询所有收藏
     */
    @PostMapping("/list")
    @ApiOperation(value = "查询所有收藏")
    public BaseResponse<List<Collect>> listCollect(HttpServletRequest request) {
        User loginUser = userService.getLoginUser(request);
        Long loginUserId = loginUser.getId();
        LambdaQueryWrapper<Collect> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(Collect::getUserId, loginUserId);
        List<Collect> list = collectService.list(wrapper);
        return ResultUtils.success(list);
    }
}
