package com.cj.jiaqingjiayi.service.impl;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.domain.Appointments;
import com.cj.jiaqingjiayi.model.domain.Business;
import com.cj.jiaqingjiayi.model.domain.Manicurist;
import com.cj.jiaqingjiayi.service.AppointmentsService;
import com.cj.jiaqingjiayi.mapper.AppointmentsMapper;
import com.cj.jiaqingjiayi.service.BusinessService;
import com.cj.jiaqingjiayi.service.ManicuristService;
import com.cj.jiaqingjiayi.utils.RegexUtils;
import javassist.expr.NewArray;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;


import javax.annotation.Resource;
import java.util.Date;

/**
* @author 高木
* @description 针对表【appointments(预约表)】的数据库操作Service实现
* @createDate 2024-11-05 19:07:40
*/
@Service
public class AppointmentsServiceImpl extends ServiceImpl<AppointmentsMapper, Appointments>
    implements AppointmentsService{

    @Resource
    private BusinessService businessService;

    @Resource
    private ManicuristService manicuristService;

    @Override
    public void valid(Appointments appointments) {
        String userName = appointments.getUsername();
        String phone = appointments.getPhone();
        Date appointmentTime = appointments.getAppointmentTime();

        if (StringUtils.isAnyBlank(userName, phone)){
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "信息不全");
        }

        if (appointmentTime == null){
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "信息不全");
        }

        if (StringUtils.isNotBlank(phone)){
            boolean phoneInvalid = RegexUtils.isPhoneInvalid(phone);
            ThrowUtils.throwIf(phoneInvalid, ErrorCode.PARAMS_ERROR, "手机号格式错误");
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Long addAppointments(Appointments appointments) {
        ThrowUtils.throwIf(appointments == null, ErrorCode.NULL_ERROR);

        String businessName = appointments.getBusinessName();
        String manicuristName = appointments.getManicuristName();

        //拿到美甲师的id(是不是麻烦了呢？)
        QueryWrapper<Manicurist> manicuristQueryWrapper = new QueryWrapper<>();
        manicuristQueryWrapper.eq("manicuristName", manicuristName);
        Manicurist manicurist = manicuristService.getOne(manicuristQueryWrapper);
        if (manicurist != null){
            Long manicuristId = manicurist.getId();
            appointments.setManicuristId(manicuristId);
        }

        //拿到商家的id
        QueryWrapper<Business> businessQueryWrapper = new QueryWrapper<>();
        businessQueryWrapper.eq("businessName", businessName);
        Business business = businessService.getOne(businessQueryWrapper);
        Long businessId = business.getId();

        //设置给预约表
        appointments.setBusinessId(businessId);

        boolean save = this.save(appointments);

        ThrowUtils.throwIf(!save, ErrorCode.PARAMS_ERROR);

        return appointments.getId();
    }
}




