package com.cj.jiaqingjiayi.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.domain.Business;
import com.cj.jiaqingjiayi.model.domain.Specifications;
import com.cj.jiaqingjiayi.model.request.attribute.AttributeAddRequest;
import com.cj.jiaqingjiayi.model.request.attribute.AttributeUpdateRequest;
import com.cj.jiaqingjiayi.model.vo.SpecificationsVO;
import com.cj.jiaqingjiayi.service.AttributeService;
import com.cj.jiaqingjiayi.service.BusinessService;
import com.cj.jiaqingjiayi.service.SpecificationsService;
import com.cj.jiaqingjiayi.mapper.SpecificationsMapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
* @author 高木
* @description 针对表【specifications(规格表)】的数据库操作Service实现
* @createDate 2024-08-21 16:20:48
*/
@Service
public class SpecificationsServiceImpl extends ServiceImpl<SpecificationsMapper, Specifications>
    implements SpecificationsService{

    @Resource
    private BusinessService businessService;

    @Resource
    private AttributeService attributeService;

    @Override
    public void validSpecifications(Specifications specifications, boolean update) {
        if (specifications == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        String specificationsName = specifications.getSpecificationsName();
        Long id = specifications.getId();

        if (update) {
            ThrowUtils.throwIf(id == null, ErrorCode.PARAMS_ERROR,"请提供规格id");
        }

        if (StringUtils.isBlank(specificationsName)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "请填写规格名称");
        }
    }

    @Override
    public Boolean addSpecifications(Specifications specifications, List<AttributeAddRequest> attributeAddRequests, HttpServletRequest request) {
        //获取当前商户
        Business loginBusiness = businessService.getLoginBusiness(request);
        Long businessId = loginBusiness.getId();

        //保存规格
        specifications.setBusinessId(businessId);
        boolean save = this.save(specifications);
        ThrowUtils.throwIf(!save, ErrorCode.PARAMS_ERROR);
        Long specificationsId = specifications.getId();
        return attributeService.addAttribute(attributeAddRequests, businessId, specificationsId);
    }

    @Override
    public Boolean updateSpecifications(Specifications specifications, List<AttributeUpdateRequest> attributeUpdateRequests, HttpServletRequest request) {
        Long specificationsId = specifications.getId();
        //获取当前登录商家信息
        Business loginBusiness = businessService.getLoginBusiness(request);
        Long businessId = loginBusiness.getId();
        //更新规格信息
        specifications.setBusinessId(businessId);
        boolean update = this.updateById(specifications);
        ThrowUtils.throwIf(!update, ErrorCode.OPERATION_ERROR);
        //更新规格的属性信息
        return attributeService.updateAttribute(attributeUpdateRequests, businessId, specificationsId);
    }

    @Override
    public List<SpecificationsVO> getSpecificationsVO(List<Specifications> specificationsList) {
        if (CollectionUtils.isEmpty(specificationsList)){
            return new ArrayList<>();
        }
        return specificationsList.stream().map(item ->{
            SpecificationsVO specificationsVO = new SpecificationsVO();
            BeanUtils.copyProperties(item,specificationsVO);
            return specificationsVO;
        }).collect(Collectors.toList());
    }
}




